@@ -1,14 +1,19 @@
 import os
-from typing import AsyncGenerator, Union
+from typing import Union, AsyncGenerator
 
 from agentex.lib import adk
-from agentex.lib.sdk.fastacp.fastacp import FastACP
 from agentex.lib.types.acp import SendMessageParams
-from agentex.lib.types.llm_messages import AssistantMessage, LLMConfig, SystemMessage, UserMessage
-from agentex.types.task_message_update import StreamTaskMessageDelta, StreamTaskMessageDone, StreamTaskMessageFull, TaskMessageUpdate
-from agentex.types.task_message_delta import TextDelta
 from agentex.lib.utils.model_utils import BaseModel
-from agentex.types.task_message_content import TaskMessageContent, TextContent
+from agentex.lib.types.llm_messages import LLMConfig, UserMessage, SystemMessage, AssistantMessage
+from agentex.lib.sdk.fastacp.fastacp import FastACP
+from agentex.types.task_message_delta import TextDelta
+from agentex.types.task_message_update import (
+    TaskMessageUpdate,
+    StreamTaskMessageDone,
+    StreamTaskMessageFull,
+    StreamTaskMessageDelta,
+)
+from agentex.types.task_message_content import TextContent, TaskMessageContent
 
 # Create an ACP server
 acp = FastACP.create(
@@ -36,11 +41,11 @@ async def handle_message_send(
     if not params.content:
         return
 
-    if params.content.type != "text":
-        raise ValueError(f"Expected text message, got {params.content.type}")
+    if not hasattr(params.content, 'type') or params.content.type != "text":
+        raise ValueError(f"Expected text message, got {getattr(params.content, 'type', 'unknown')}")
 
-    if params.content.author != "user":
-        raise ValueError(f"Expected user message, got {params.content.author}")
+    if not hasattr(params.content, 'author') or params.content.author != "user":
+        raise ValueError(f"Expected user message, got {getattr(params.content, 'author', 'unknown')}")
     
     if not os.environ.get("OPENAI_API_KEY"):
         yield StreamTaskMessageFull(
@@ -67,9 +72,9 @@ async def handle_message_send(
     llm_messages = [
         SystemMessage(content=state.system_prompt),
         *[
-            UserMessage(content=message.content.content) if message.content.author == "user" else AssistantMessage(content=message.content.content)
+            UserMessage(content=getattr(message.content, 'content', '')) if getattr(message.content, 'author', None) == "user" else AssistantMessage(content=getattr(message.content, 'content', ''))
             for message in task_messages
-            if message.content and message.content.type == "text"
+            if message.content and getattr(message.content, 'type', None) == "text"
         ]
     ]
     
@@ -92,7 +97,7 @@ async def handle_message_send(
             yield StreamTaskMessageDelta(
                 type="delta",
                 index=message_index,
-                delta=TextDelta(text_delta=chunk.choices[0].delta.content or ""),
+                delta=TextDelta(type="text", text_delta=chunk.choices[0].delta.content or ""),
             )
 
     yield StreamTaskMessageDone(
