@@ -1,10 +1,12 @@
+# ruff: noqa: I001
+# Import order matters - AsyncTracer must come after client import to avoid circular imports
 from datetime import timedelta
 from typing import Any, List
 
 from agentex.types import Event
 from temporalio.common import RetryPolicy
 
-from agentex import AsyncAgentex
+from agentex import AsyncAgentex  # noqa: F401
 from agentex.lib.adk.utils._modules.client import create_async_agentex_client
 from agentex.lib.core.services.adk.acp.acp import ACPService
 from agentex.lib.core.temporal.activities.activity_helpers import ActivityHelpers
