@@ -1,37 +1,37 @@
 import builtins
 from pathlib import Path
 
-import questionary
 import typer
+import questionary
 from rich import print_json
-from rich.console import Console
 from rich.panel import Panel
+from rich.console import Console
 
+from agentex import Agentex
+from agentex.lib.cli.debug import DebugMode, DebugConfig
+from agentex.lib.utils.logging import make_logger
+from agentex.lib.cli.utils.cli_utils import handle_questionary_cancellation
+from agentex.lib.sdk.config.validation import (
+    EnvironmentsValidationError,
+    generate_helpful_error_message,
+    validate_manifest_and_environments,
+)
+from agentex.lib.cli.utils.kubectl_utils import (
+    validate_namespace,
+    check_and_switch_cluster_context,
+)
+from agentex.lib.sdk.config.agent_manifest import AgentManifest
 from agentex.lib.cli.handlers.agent_handlers import (
+    run_agent,
     build_agent,
-    run_agent,
 )
-from agentex.lib.cli.debug import DebugConfig, DebugMode
-from agentex.lib.cli.handlers.cleanup_handlers import cleanup_agent_workflows
 from agentex.lib.cli.handlers.deploy_handlers import (
-    DeploymentError,
     HelmError,
+    DeploymentError,
     InputDeployOverrides,
     deploy_agent,
 )
-from agentex.lib.sdk.config.validation import (
-    validate_manifest_and_environments, 
-    EnvironmentsValidationError,
-    generate_helpful_error_message
-)
-from agentex.lib.cli.utils.cli_utils import handle_questionary_cancellation
-from agentex.lib.cli.utils.kubectl_utils import (
-    check_and_switch_cluster_context,
-    validate_namespace,
-)
-from agentex import Agentex
-from agentex.lib.sdk.config.agent_manifest import AgentManifest
-from agentex.lib.utils.logging import make_logger
+from agentex.lib.cli.handlers.cleanup_handlers import cleanup_agent_workflows
 
 logger = make_logger(__name__)
 console = Console()
@@ -293,10 +293,10 @@ def deploy(
         except EnvironmentsValidationError as e:
             error_msg = generate_helpful_error_message(e, "Environment validation failed")
             console.print(f"[red]Configuration Error:[/red]\n{error_msg}")
-            raise typer.Exit(1)
+            raise typer.Exit(1) from e
         except Exception as e:
             console.print(f"[red]Error:[/red] Failed to validate configuration: {e}")
-            raise typer.Exit(1)
+            raise typer.Exit(1) from e
 
         # Load manifest for credential validation
         manifest_obj = AgentManifest.from_yaml(str(manifest_path))
