@@ -1,51 +1,51 @@
 # Standard library imports
-from contextlib import AsyncExitStack, asynccontextmanager
 from typing import Any, Literal
+from contextlib import AsyncExitStack, asynccontextmanager
 
+from mcp import StdioServerParameters
 from agents import Agent, Runner, RunResult, RunResultStreaming
+from pydantic import BaseModel
+from agents.mcp import MCPServerStdio
 from agents.agent import StopAtTools, ToolsToFinalOutputFunction
 from agents.guardrail import InputGuardrail, OutputGuardrail
 from agents.exceptions import InputGuardrailTripwireTriggered, OutputGuardrailTripwireTriggered
-from agents.mcp import MCPServerStdio
-from mcp import StdioServerParameters
 from openai.types.responses import (
     ResponseCompletedEvent,
-    ResponseFunctionWebSearch,
-    ResponseCodeInterpreterToolCall,
-    ResponseOutputItemDoneEvent,
     ResponseTextDeltaEvent,
-    ResponseReasoningSummaryTextDeltaEvent,
-    ResponseReasoningSummaryTextDoneEvent,
-    ResponseReasoningTextDeltaEvent,
+    ResponseFunctionWebSearch,
+    ResponseOutputItemDoneEvent,
     ResponseReasoningTextDoneEvent,
+    ResponseCodeInterpreterToolCall,
+    ResponseReasoningTextDeltaEvent,
+    ResponseReasoningSummaryTextDoneEvent,
+    ResponseReasoningSummaryTextDeltaEvent,
 )
-from pydantic import BaseModel
 
 # Local imports
 from agentex import AsyncAgentex
+from agentex.lib.utils import logging
+from agentex.lib.utils.mcp import redact_mcp_server_params
+from agentex.lib.utils.temporal import heartbeat_if_in_workflow
+from agentex.lib.core.tracing.tracer import AsyncTracer
+from agentex.types.task_message_delta import (
+    TextDelta,
+    ReasoningContentDelta,
+    ReasoningSummaryDelta,
+)
+from agentex.types.task_message_update import (
+    StreamTaskMessageFull,
+    StreamTaskMessageDelta,
+)
+from agentex.types.task_message_content import (
+    TextContent,
+    ReasoningContent,
+    ToolRequestContent,
+    ToolResponseContent,
+)
 from agentex.lib.core.services.adk.streaming import (
     StreamingService,
     StreamingTaskMessageContext,
 )
-from agentex.lib.core.tracing.tracer import AsyncTracer
-from agentex.types.task_message_update import (
-    StreamTaskMessageDelta,
-    StreamTaskMessageFull,
-)
-from agentex.types.task_message_delta import (
-    TextDelta,
-    ReasoningSummaryDelta,
-    ReasoningContentDelta,
-)
-from agentex.types.task_message_content import (
-    ReasoningContent,
-    TextContent,
-    ToolRequestContent,
-    ToolResponseContent,
-)
-from agentex.lib.utils import logging
-from agentex.lib.utils.mcp import redact_mcp_server_params
-from agentex.lib.utils.temporal import heartbeat_if_in_workflow
 
 logger = logging.make_logger(__name__)
 
@@ -141,15 +141,15 @@ class OpenAIService:
             content = tool_output_item["output"]
         else:
             # Attribute access for structured objects
-            call_id = getattr(tool_output_item, "call_id", None)
-            content = getattr(tool_output_item, "output", None)
+            call_id = getattr(tool_output_item, "call_id", "")
+            content = getattr(tool_output_item, "output", "")
 
         # Get the name from the tool call map using generic approach
         tool_call = tool_call_map[call_id]
         if hasattr(tool_call, "name"):
-            tool_name = getattr(tool_call, "name")
+            tool_name = tool_call.name
         elif hasattr(tool_call, "type"):
-            tool_name = getattr(tool_call, "type")
+            tool_name = tool_call.type
         else:
             tool_name = type(tool_call).__name__
 
@@ -176,7 +176,7 @@ class OpenAIService:
         input_guardrails: list[InputGuardrail] | None = None,
         output_guardrails: list[OutputGuardrail] | None = None,
         max_turns: int | None = None,
-        previous_response_id: str | None = None,
+        previous_response_id: str | None = None,  # noqa: ARG002
     ) -> RunResult:
         """
         Run an agent without streaming or TaskMessage creation.
@@ -208,6 +208,8 @@ class OpenAIService:
         """
         redacted_params = redact_mcp_server_params(mcp_server_params)
 
+        if self.tracer is None:
+            raise RuntimeError("Tracer not initialized - ensure tracer is provided to OpenAIService")
         trace = self.tracer.trace(trace_id)
         async with trace.span(
             parent_id=parent_span_id,
@@ -230,8 +232,11 @@ class OpenAIService:
             heartbeat_if_in_workflow("run agent")
 
             async with mcp_server_context(mcp_server_params, mcp_timeout_seconds) as servers:
-                tools = [tool.to_oai_function_tool() for tool in tools] if tools else []
-                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []
+                tools = [
+                    tool.to_oai_function_tool() if hasattr(tool, 'to_oai_function_tool') else tool  # type: ignore[attr-defined]
+                    for tool in tools
+                ] if tools else []
+                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []  # type: ignore[misc]
 
                 agent_kwargs = {
                     "name": agent_name,
@@ -245,7 +250,10 @@ class OpenAIService:
                     "tool_use_behavior": tool_use_behavior,
                 }
                 if model_settings is not None:
-                    agent_kwargs["model_settings"] = model_settings.to_oai_model_settings()
+                    agent_kwargs["model_settings"] = (
+                        model_settings.to_oai_model_settings() if hasattr(model_settings, 'to_oai_model_settings')  # type: ignore[attr-defined]
+                        else model_settings
+                    )
                 if input_guardrails is not None:
                     agent_kwargs["input_guardrails"] = input_guardrails
                 if output_guardrails is not None:
@@ -303,7 +311,7 @@ class OpenAIService:
         input_guardrails: list[InputGuardrail] | None = None,
         output_guardrails: list[OutputGuardrail] | None = None,
         max_turns: int | None = None,
-        previous_response_id: str | None = None,
+        previous_response_id: str | None = None,  # noqa: ARG002
     ) -> RunResult:
         """
         Run an agent with automatic TaskMessage creation.
@@ -337,6 +345,8 @@ class OpenAIService:
 
         redacted_params = redact_mcp_server_params(mcp_server_params)
 
+        if self.tracer is None:
+            raise RuntimeError("Tracer not initialized - ensure tracer is provided to OpenAIService")
         trace = self.tracer.trace(trace_id)
         async with trace.span(
             parent_id=parent_span_id,
@@ -360,8 +370,11 @@ class OpenAIService:
             heartbeat_if_in_workflow("run agent auto send")
 
             async with mcp_server_context(mcp_server_params, mcp_timeout_seconds) as servers:
-                tools = [tool.to_oai_function_tool() for tool in tools] if tools else []
-                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []
+                tools = [
+                    tool.to_oai_function_tool() if hasattr(tool, 'to_oai_function_tool') else tool  # type: ignore[attr-defined]
+                    for tool in tools
+                ] if tools else []
+                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []  # type: ignore[misc]
                 agent_kwargs = {
                     "name": agent_name,
                     "instructions": agent_instructions,
@@ -374,7 +387,10 @@ class OpenAIService:
                     "tool_use_behavior": tool_use_behavior,
                 }
                 if model_settings is not None:
-                    agent_kwargs["model_settings"] = model_settings.to_oai_model_settings()
+                    agent_kwargs["model_settings"] = (
+                        model_settings.to_oai_model_settings() if hasattr(model_settings, 'to_oai_model_settings')  # type: ignore[attr-defined]
+                        else model_settings
+                    )
                 if input_guardrails is not None:
                     agent_kwargs["input_guardrails"] = input_guardrails
                 if output_guardrails is not None:
@@ -414,7 +430,7 @@ class OpenAIService:
                     if item.type == "message_output_item":
                         text_content = TextContent(
                             author="agent",
-                            content=item.raw_item.content[0].text,
+                            content=item.raw_item.content[0].text,  # type: ignore[union-attr]
                         )
                         # Create message for the final result using streaming context
                         async with self.streaming_service.streaming_task_message_context(
@@ -504,7 +520,7 @@ class OpenAIService:
         input_guardrails: list[InputGuardrail] | None = None,
         output_guardrails: list[OutputGuardrail] | None = None,
         max_turns: int | None = None,
-        previous_response_id: str | None = None,
+        previous_response_id: str | None = None,  # noqa: ARG002
     ) -> RunResultStreaming:
         """
         Run an agent with streaming enabled but no TaskMessage creation.
@@ -534,6 +550,8 @@ class OpenAIService:
         Returns:
             RunResultStreaming: The result of the agent run with streaming.
         """
+        if self.tracer is None:
+            raise RuntimeError("Tracer not initialized - ensure tracer is provided to OpenAIService")
         trace = self.tracer.trace(trace_id)
         redacted_params = redact_mcp_server_params(mcp_server_params)
 
@@ -558,8 +576,11 @@ class OpenAIService:
             heartbeat_if_in_workflow("run agent streamed")
 
             async with mcp_server_context(mcp_server_params, mcp_timeout_seconds) as servers:
-                tools = [tool.to_oai_function_tool() for tool in tools] if tools else []
-                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []
+                tools = [
+                    tool.to_oai_function_tool() if hasattr(tool, 'to_oai_function_tool') else tool  # type: ignore[attr-defined]
+                    for tool in tools
+                ] if tools else []
+                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []  # type: ignore[misc]
                 agent_kwargs = {
                     "name": agent_name,
                     "instructions": agent_instructions,
@@ -572,7 +593,10 @@ class OpenAIService:
                     "tool_use_behavior": tool_use_behavior,
                 }
                 if model_settings is not None:
-                    agent_kwargs["model_settings"] = model_settings.to_oai_model_settings()
+                    agent_kwargs["model_settings"] = (
+                        model_settings.to_oai_model_settings() if hasattr(model_settings, 'to_oai_model_settings')  # type: ignore[attr-defined]
+                        else model_settings
+                    )
                 if input_guardrails is not None:
                     agent_kwargs["input_guardrails"] = input_guardrails
                 if output_guardrails is not None:
@@ -630,7 +654,7 @@ class OpenAIService:
         input_guardrails: list[InputGuardrail] | None = None,
         output_guardrails: list[OutputGuardrail] | None = None,
         max_turns: int | None = None,
-        previous_response_id: str | None = None,
+        previous_response_id: str | None = None,  # noqa: ARG002
     ) -> RunResultStreaming:
         """
         Run an agent with streaming enabled and automatic TaskMessage creation.
@@ -669,6 +693,8 @@ class OpenAIService:
 
         tool_call_map: dict[str, Any] = {}
 
+        if self.tracer is None:
+            raise RuntimeError("Tracer not initialized - ensure tracer is provided to OpenAIService")
         trace = self.tracer.trace(trace_id)
         redacted_params = redact_mcp_server_params(mcp_server_params)
 
@@ -694,8 +720,11 @@ class OpenAIService:
             heartbeat_if_in_workflow("run agent streamed auto send")
 
             async with mcp_server_context(mcp_server_params, mcp_timeout_seconds) as servers:
-                tools = [tool.to_oai_function_tool() for tool in tools] if tools else []
-                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []
+                tools = [
+                    tool.to_oai_function_tool() if hasattr(tool, 'to_oai_function_tool') else tool  # type: ignore[attr-defined]
+                    for tool in tools
+                ] if tools else []
+                handoffs = [Agent(**handoff.model_dump()) for handoff in handoffs] if handoffs else []  # type: ignore[misc]
                 agent_kwargs = {
                     "name": agent_name,
                     "instructions": agent_instructions,
@@ -708,7 +737,10 @@ class OpenAIService:
                     "tool_use_behavior": tool_use_behavior,
                 }
                 if model_settings is not None:
-                    agent_kwargs["model_settings"] = model_settings.to_oai_model_settings()
+                    agent_kwargs["model_settings"] = (
+                        model_settings.to_oai_model_settings() if hasattr(model_settings, 'to_oai_model_settings')  # type: ignore[attr-defined]
+                        else model_settings
+                    )
                 if input_guardrails is not None:
                     agent_kwargs["input_guardrails"] = input_guardrails
                 if output_guardrails is not None:
