@@ -2,10 +2,10 @@ from enum import Enum
 
 from temporalio import activity
 
-from agentex.lib.core.services.adk.tasks import TasksService
 from agentex.types.task import Task
 from agentex.lib.types.tracing import BaseModelWithTraceParams
 from agentex.lib.utils.logging import make_logger
+from agentex.lib.core.services.adk.tasks import TasksService
 
 logger = make_logger(__name__)
 
@@ -40,7 +40,7 @@ class TasksActivities:
 
     @activity.defn(name=TasksActivityName.DELETE_TASK)
     async def delete_task(self, params: DeleteTaskParams) -> Task:
-        return await self._tasks_service.delete_task(
+        return await self._tasks_service.delete_task(  # type: ignore[return-value]
             task_id=params.task_id,
             task_name=params.task_name,
             trace_id=params.trace_id,
