@@ -1,32 +1,35 @@
+import uuid
 import asyncio
 import inspect
-from datetime import datetime
-from collections.abc import AsyncGenerator, Awaitable, Callable
-from contextlib import asynccontextmanager
 from typing import Any
+from datetime import datetime
+from contextlib import asynccontextmanager
+from collections.abc import Callable, Awaitable, AsyncGenerator
 
 import uvicorn
 from fastapi import FastAPI, Request
-from fastapi.responses import StreamingResponse
 from pydantic import TypeAdapter, ValidationError
+from fastapi.responses import StreamingResponse
+from starlette.middleware.base import BaseHTTPMiddleware
+
+from agentex.lib.types.acp import (
+    RPC_SYNC_METHODS,
+    PARAMS_MODEL_BY_METHOD,
+    RPCMethod,
+    SendEventParams,
+    CancelTaskParams,
+    CreateTaskParams,
+    SendMessageParams,
+)
+from agentex.lib.utils.logging import make_logger, ctx_var_request_id
+from agentex.lib.types.json_rpc import JSONRPCError, JSONRPCRequest, JSONRPCResponse
+from agentex.lib.utils.model_utils import BaseModel
+from agentex.lib.utils.registration import register_agent
 
 # from agentex.lib.sdk.fastacp.types import BaseACPConfig
 from agentex.lib.environment_variables import EnvironmentVariables, refreshed_environment_variables
-from agentex.lib.types.acp import (
-    PARAMS_MODEL_BY_METHOD,
-    RPC_SYNC_METHODS,
-    CancelTaskParams,
-    CreateTaskParams,
-    RPCMethod,
-    SendEventParams,
-    SendMessageParams,
-)
-from agentex.lib.types.json_rpc import JSONRPCError, JSONRPCRequest, JSONRPCResponse
-from agentex.types.task_message_update import StreamTaskMessageFull, TaskMessageUpdate
+from agentex.types.task_message_update import TaskMessageUpdate, StreamTaskMessageFull
 from agentex.types.task_message_content import TaskMessageContent
-from agentex.lib.utils.logging import make_logger
-from agentex.lib.utils.model_utils import BaseModel
-from agentex.lib.utils.registration import register_agent
 from agentex.lib.sdk.fastacp.base.constants import (
     FASTACP_HEADER_SKIP_EXACT,
     FASTACP_HEADER_SKIP_PREFIXES,
@@ -38,6 +41,19 @@ logger = make_logger(__name__)
 task_message_update_adapter = TypeAdapter(TaskMessageUpdate)
 
 
+class RequestIDMiddleware(BaseHTTPMiddleware):
+    """Middleware to extract or generate request IDs and add them to logs and response headers"""
+
+    async def dispatch(self, request: Request, call_next):  # type: ignore[override]
+        # Extract request ID from header or generate a new one if there isn't one
+        request_id = request.headers.get("x-request-id") or uuid.uuid4().hex
+        # Store request ID in request state for access in handlers
+        ctx_var_request_id.set(request_id)
+        # Process request
+        response = await call_next(request)
+        return response
+
+
 class BaseACPServer(FastAPI):
     """
     AsyncAgentACP provides RPC-style hooks for agent events and commands asynchronously.
@@ -56,6 +72,8 @@ class BaseACPServer(FastAPI):
         self.post("/api")(self._handle_jsonrpc)
 
         # Method handlers
+        # this just adds a request ID to the request and response headers
+        self.add_middleware(RequestIDMiddleware)
         self._handlers: dict[RPCMethod, Callable] = {}
 
     @classmethod
@@ -72,7 +90,7 @@ class BaseACPServer(FastAPI):
 
     def get_lifespan_function(self):
         @asynccontextmanager
-        async def lifespan_context(app: FastAPI):
+        async def lifespan_context(app: FastAPI):  # noqa: ARG001
             env_vars = EnvironmentVariables.refresh()
             if env_vars.AGENTEX_BASE_URL:
                 await register_agent(env_vars)
@@ -371,4 +389,4 @@ class BaseACPServer(FastAPI):
         """Start the Uvicorn server for async handlers."""
         uvicorn.run(self, host=host, port=port, **kwargs)
 
-    
\ No newline at end of file
+    
